# Booty Col

Booty Col is a lightweight fixed grid framework for SASS. It is heavily inspired by [Susy](https://github.com/ericam/compass-susy-plugin), and provides strong pixel-based layouts as opposed to percentage-based ones.

### Some Features

* Fixed width grids
* No required markup, only mixins
* Makes nesting fun!
* No assumptions about responsive behavior
* No need to explicitly set column widths
* Provides an API for setting column height

If your layout is way too complex to be accomplished using percentage-based widths, Booty Col is for you.

## Installation

Simply add `booty_col.scss` to your project and import it via SASS.

```css
@import "booty_col";
```

Declare the parameters of your grid using the predefined `$booty-col` variables. The framework will automatically formulate your column widths based on **a)** number of columns, **b)** overall container width, and **c)** gutter widths.

```css
$booty-cols              : 12;
$booty-width             : 960px;
$booty-gutter-width      : 20px;
$booty-side-gutter-width : 10px;
```

## Usage

Like Susy, you include the booty_col mixins directly in your CSS. You don't need to add any extra classes to your markup.

### Container

```css
.container {
  @include booty-container;
}
```

### Columns

Include the `booty-col` mixin to tell an element how many columns to take up.

```css
.sidebar {
  @include booty-cols(4); // 4 columns please!
}
```

### Heights

The `booty-height` mixin gives you the ability to set the height of an element by column width. Very useful for making squares.

```css
.sidebar {
  @include booty-cols(4);
  @include booty-height(4);
}
```

### Offsets

Shift an element around on the grid by pushing it over by a virtual number of columns.

```css
.sidebar {
  @include booty-cols(4); // 4 columns wide
  @include booty-push(2); // 2 columns over
}
```

### Omega

When an element occupies the last column(s), include `booty-omega` so the grid doesn't crumble like bleu cheese. This basically sets `margin-right` to 0.

```css
.content {
  @include booty-cols(8);
  @include booty-omega;
}
```

## Responsive

Unlike other frameworks, booty_col is not responsive out of the box. This is a good thing, since it gives you granular control over how the styles adapt from screen to screen. There are a number of possible patterns you could employ to achieve a responsive layout with booty_col, but I prefer a modular mobile-first one. Here are a couple examples:

```css
$lt_ie9: false !default;

@mixin portrait {
  $booty-cols              : 12;
  $booty-width             : 320px;
  $booty-gutter-width      : 10px;
  $booty-side-gutter-width : 20px;
  @media (min-width: 320px) and (max-width: 489px) {
    @content;
  }
}

@mixin landscape {
  $booty-cols              : 12;
  $booty-width             : 480px;
  $booty-gutter-width      : 10px;
  $booty-side-gutter-width : 20px;

  @media (min-width: 480px) and (max-width: 767px) {
    @content;
  }
}

@mixin tablet {

  $booty-cols              : 12;
  $booty-width             : 768px;
  $booty-gutter-width      : 10px;
  $booty-side-gutter-width : 40px;

  @media (min-width: 768px) and (max-width: 960px) {
    @content;
  }
}

@mixin desktop {

  $booty-cols              : 12;
  $booty-width             : 940px;
  $booty-gutter-width      : 20px;
  $booty-side-gutter-width : 10px;

  @if $lt_ie9 {
    @content;
  }
  @else {
    @media (min-width: 961px) and (max-width: 1200px) {
      @content;
    }
  }
}

@mixin big-desktop {
  $booty-cols              : 12;
  $booty-width             : 1200px;
  $booty-gutter-width      : 20px;
  $booty-side-gutter-width : 40px;

  @media (min-width: 1201px) {
    @content;
  }
}

@mixin retina {
  @media  (-webkit-min-device-pixel-ratio: 2), (-o-min-device-pixel-ratio: 3/2), (min-device-pixel-ratio: 2) {
    @content;
  }
}

.thingy-thing {
  @include breakpoint($mobile-portrait) {
    // ...
  }
  @include breakpoint($mobile-landscape) {
    // ...
  }
  @include breakpoint($tablet) {
	  // ...
  }
  @include breakpoint($desktop) {
    // ...
  }
  @include breakpoint($desktop-big) {
    // ...
  }
}

```

Another option:

```css
@import "booty_col";

// Mobile ----------------------------------

$booty-cols              : 12;
$booty-width             : 320px;
$booty-gutter-width      : 0px;
$booty-side-gutter-width : 0px;

// More styles!


// Mobile Landscape ------------------------

@media (max-width: 480px) {

  $booty-width : 480px;

  // More styles!

}

// Tablet ----------------------------------

@media (max-width: 768px) {

  $booty-width        : 768px;
  $booty-gutter-width : 10px;

  // More styles!

}

// Desktop ---------------------------------

@media (min-width: 768px) and (max-width: 980px) {

  $booty-width             : 960px;
  $booty-gutter-width      : 20px;
  $booty-side-gutter-width : 10px;

  // More styles!

}

// Big Desktop -----------------------------

@media (min-width: 1200px) {

  $booty-width             : 1200px;
  $booty-gutter-width      : 20px;
  $booty-side-gutter-width : 10px;

  // More styles!

}
```

## Contributors

* Alexander Strobbe - [@flexid_](http://twitter.com/#!/flexid_)
